API Reference
=============

.. autosummary::
   intake_xarray.netcdf.NetCDFSource
   intake_xarray.opendap.OpenDapSource
   intake_xarray.xzarr.ZarrSource
   intake_xarray.raster.RasterIOSource
   intake_xarray.image.ImageSource

.. autoclass:: intake_xarray.netcdf.NetCDFSource
   :members:

.. autoclass:: intake_xarray.netcdf.OpenDapSource
   :members:

.. autoclass:: intake_xarray.xzarr.ZarrSource
   :members:

.. autoclass:: intake_xarray.raster.RasterIOSource
   :members:

.. autoclass:: intake_xarray.image.ImageSource
   :members:
